/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NetworkSecurityInterceptDeploymentConfig extends cdktf.TerraformMetaArguments {
    /**
    * User-provided description of the deployment.
    * Used as additional context for the deployment.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_deployment#description NetworkSecurityInterceptDeployment#description}
    */
    readonly description?: string;
    /**
    * The regional forwarding rule that fronts the interceptors, for example:
    * 'projects/123456789/regions/us-central1/forwardingRules/my-rule'.
    * See https://google.aip.dev/124.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_deployment#forwarding_rule NetworkSecurityInterceptDeployment#forwarding_rule}
    */
    readonly forwardingRule: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_deployment#id NetworkSecurityInterceptDeployment#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The deployment group that this deployment is a part of, for example:
    * 'projects/123456789/locations/global/interceptDeploymentGroups/my-dg'.
    * See https://google.aip.dev/124.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_deployment#intercept_deployment_group NetworkSecurityInterceptDeployment#intercept_deployment_group}
    */
    readonly interceptDeploymentGroup: string;
    /**
    * The ID to use for the new deployment, which will become the final
    * component of the deployment's resource name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_deployment#intercept_deployment_id NetworkSecurityInterceptDeployment#intercept_deployment_id}
    */
    readonly interceptDeploymentId: string;
    /**
    * Labels are key/value pairs that help to organize and filter resources.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_deployment#labels NetworkSecurityInterceptDeployment#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The cloud location of the deployment, e.g. 'us-central1-a' or 'asia-south1-b'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_deployment#location NetworkSecurityInterceptDeployment#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_deployment#project NetworkSecurityInterceptDeployment#project}
    */
    readonly project?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_deployment#timeouts NetworkSecurityInterceptDeployment#timeouts}
    */
    readonly timeouts?: NetworkSecurityInterceptDeploymentTimeouts;
}
export interface NetworkSecurityInterceptDeploymentTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_deployment#create NetworkSecurityInterceptDeployment#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_deployment#delete NetworkSecurityInterceptDeployment#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_deployment#update NetworkSecurityInterceptDeployment#update}
    */
    readonly update?: string;
}
export declare function networkSecurityInterceptDeploymentTimeoutsToTerraform(struct?: NetworkSecurityInterceptDeploymentTimeouts | cdktf.IResolvable): any;
export declare function networkSecurityInterceptDeploymentTimeoutsToHclTerraform(struct?: NetworkSecurityInterceptDeploymentTimeouts | cdktf.IResolvable): any;
export declare class NetworkSecurityInterceptDeploymentTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NetworkSecurityInterceptDeploymentTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: NetworkSecurityInterceptDeploymentTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_deployment google_network_security_intercept_deployment}
*/
export declare class NetworkSecurityInterceptDeployment extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_network_security_intercept_deployment";
    /**
    * Generates CDKTF code for importing a NetworkSecurityInterceptDeployment resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NetworkSecurityInterceptDeployment to import
    * @param importFromId The id of the existing NetworkSecurityInterceptDeployment that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_deployment#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NetworkSecurityInterceptDeployment to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_deployment google_network_security_intercept_deployment} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NetworkSecurityInterceptDeploymentConfig
    */
    constructor(scope: Construct, id: string, config: NetworkSecurityInterceptDeploymentConfig);
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _forwardingRule?;
    get forwardingRule(): string;
    set forwardingRule(value: string);
    get forwardingRuleInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _interceptDeploymentGroup?;
    get interceptDeploymentGroup(): string;
    set interceptDeploymentGroup(value: string);
    get interceptDeploymentGroupInput(): string | undefined;
    private _interceptDeploymentId?;
    get interceptDeploymentId(): string;
    set interceptDeploymentId(value: string);
    get interceptDeploymentIdInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get reconciling(): cdktf.IResolvable;
    get state(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): NetworkSecurityInterceptDeploymentTimeoutsOutputReference;
    putTimeouts(value: NetworkSecurityInterceptDeploymentTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | NetworkSecurityInterceptDeploymentTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
