/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NetworkSecurityInterceptEndpointGroupAssociationConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group_association#id NetworkSecurityInterceptEndpointGroupAssociation#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The endpoint group that this association is connected to, for example:
    * 'projects/123456789/locations/global/interceptEndpointGroups/my-eg'.
    * See https://google.aip.dev/124.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group_association#intercept_endpoint_group NetworkSecurityInterceptEndpointGroupAssociation#intercept_endpoint_group}
    */
    readonly interceptEndpointGroup: string;
    /**
    * The ID to use for the new association, which will become the final
    * component of the endpoint group's resource name. If not provided, the
    * server will generate a unique ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group_association#intercept_endpoint_group_association_id NetworkSecurityInterceptEndpointGroupAssociation#intercept_endpoint_group_association_id}
    */
    readonly interceptEndpointGroupAssociationId?: string;
    /**
    * Labels are key/value pairs that help to organize and filter resources.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group_association#labels NetworkSecurityInterceptEndpointGroupAssociation#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The cloud location of the association, currently restricted to 'global'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group_association#location NetworkSecurityInterceptEndpointGroupAssociation#location}
    */
    readonly location: string;
    /**
    * The VPC network that is associated. for example:
    * 'projects/123456789/global/networks/my-network'.
    * See https://google.aip.dev/124.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group_association#network NetworkSecurityInterceptEndpointGroupAssociation#network}
    */
    readonly network: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group_association#project NetworkSecurityInterceptEndpointGroupAssociation#project}
    */
    readonly project?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group_association#timeouts NetworkSecurityInterceptEndpointGroupAssociation#timeouts}
    */
    readonly timeouts?: NetworkSecurityInterceptEndpointGroupAssociationTimeouts;
}
export interface NetworkSecurityInterceptEndpointGroupAssociationLocations {
}
export declare function networkSecurityInterceptEndpointGroupAssociationLocationsToTerraform(struct?: NetworkSecurityInterceptEndpointGroupAssociationLocations): any;
export declare function networkSecurityInterceptEndpointGroupAssociationLocationsToHclTerraform(struct?: NetworkSecurityInterceptEndpointGroupAssociationLocations): any;
export declare class NetworkSecurityInterceptEndpointGroupAssociationLocationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NetworkSecurityInterceptEndpointGroupAssociationLocations | undefined;
    set internalValue(value: NetworkSecurityInterceptEndpointGroupAssociationLocations | undefined);
    get location(): string;
    get state(): string;
}
export declare class NetworkSecurityInterceptEndpointGroupAssociationLocationsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NetworkSecurityInterceptEndpointGroupAssociationLocationsOutputReference;
}
export interface NetworkSecurityInterceptEndpointGroupAssociationLocationsDetails {
}
export declare function networkSecurityInterceptEndpointGroupAssociationLocationsDetailsToTerraform(struct?: NetworkSecurityInterceptEndpointGroupAssociationLocationsDetails): any;
export declare function networkSecurityInterceptEndpointGroupAssociationLocationsDetailsToHclTerraform(struct?: NetworkSecurityInterceptEndpointGroupAssociationLocationsDetails): any;
export declare class NetworkSecurityInterceptEndpointGroupAssociationLocationsDetailsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NetworkSecurityInterceptEndpointGroupAssociationLocationsDetails | undefined;
    set internalValue(value: NetworkSecurityInterceptEndpointGroupAssociationLocationsDetails | undefined);
    get location(): string;
    get state(): string;
}
export declare class NetworkSecurityInterceptEndpointGroupAssociationLocationsDetailsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NetworkSecurityInterceptEndpointGroupAssociationLocationsDetailsOutputReference;
}
export interface NetworkSecurityInterceptEndpointGroupAssociationTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group_association#create NetworkSecurityInterceptEndpointGroupAssociation#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group_association#delete NetworkSecurityInterceptEndpointGroupAssociation#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group_association#update NetworkSecurityInterceptEndpointGroupAssociation#update}
    */
    readonly update?: string;
}
export declare function networkSecurityInterceptEndpointGroupAssociationTimeoutsToTerraform(struct?: NetworkSecurityInterceptEndpointGroupAssociationTimeouts | cdktf.IResolvable): any;
export declare function networkSecurityInterceptEndpointGroupAssociationTimeoutsToHclTerraform(struct?: NetworkSecurityInterceptEndpointGroupAssociationTimeouts | cdktf.IResolvable): any;
export declare class NetworkSecurityInterceptEndpointGroupAssociationTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NetworkSecurityInterceptEndpointGroupAssociationTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: NetworkSecurityInterceptEndpointGroupAssociationTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group_association google_network_security_intercept_endpoint_group_association}
*/
export declare class NetworkSecurityInterceptEndpointGroupAssociation extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_network_security_intercept_endpoint_group_association";
    /**
    * Generates CDKTF code for importing a NetworkSecurityInterceptEndpointGroupAssociation resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NetworkSecurityInterceptEndpointGroupAssociation to import
    * @param importFromId The id of the existing NetworkSecurityInterceptEndpointGroupAssociation that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group_association#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NetworkSecurityInterceptEndpointGroupAssociation to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group_association google_network_security_intercept_endpoint_group_association} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NetworkSecurityInterceptEndpointGroupAssociationConfig
    */
    constructor(scope: Construct, id: string, config: NetworkSecurityInterceptEndpointGroupAssociationConfig);
    get createTime(): string;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _interceptEndpointGroup?;
    get interceptEndpointGroup(): string;
    set interceptEndpointGroup(value: string);
    get interceptEndpointGroupInput(): string | undefined;
    private _interceptEndpointGroupAssociationId?;
    get interceptEndpointGroupAssociationId(): string;
    set interceptEndpointGroupAssociationId(value: string);
    resetInterceptEndpointGroupAssociationId(): void;
    get interceptEndpointGroupAssociationIdInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _locations;
    get locations(): NetworkSecurityInterceptEndpointGroupAssociationLocationsList;
    private _locationsDetails;
    get locationsDetails(): NetworkSecurityInterceptEndpointGroupAssociationLocationsDetailsList;
    get name(): string;
    private _network?;
    get network(): string;
    set network(value: string);
    get networkInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get reconciling(): cdktf.IResolvable;
    get state(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): NetworkSecurityInterceptEndpointGroupAssociationTimeoutsOutputReference;
    putTimeouts(value: NetworkSecurityInterceptEndpointGroupAssociationTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | NetworkSecurityInterceptEndpointGroupAssociationTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
