/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NetworkSecurityInterceptEndpointGroupConfig extends cdktf.TerraformMetaArguments {
    /**
    * User-provided description of the endpoint group.
    * Used as additional context for the endpoint group.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group#description NetworkSecurityInterceptEndpointGroup#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group#id NetworkSecurityInterceptEndpointGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The deployment group that this endpoint group is connected to, for example:
    * 'projects/123456789/locations/global/interceptDeploymentGroups/my-dg'.
    * See https://google.aip.dev/124.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group#intercept_deployment_group NetworkSecurityInterceptEndpointGroup#intercept_deployment_group}
    */
    readonly interceptDeploymentGroup: string;
    /**
    * The ID to use for the endpoint group, which will become the final component
    * of the endpoint group's resource name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group#intercept_endpoint_group_id NetworkSecurityInterceptEndpointGroup#intercept_endpoint_group_id}
    */
    readonly interceptEndpointGroupId: string;
    /**
    * Labels are key/value pairs that help to organize and filter resources.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group#labels NetworkSecurityInterceptEndpointGroup#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The cloud location of the endpoint group, currently restricted to 'global'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group#location NetworkSecurityInterceptEndpointGroup#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group#project NetworkSecurityInterceptEndpointGroup#project}
    */
    readonly project?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group#timeouts NetworkSecurityInterceptEndpointGroup#timeouts}
    */
    readonly timeouts?: NetworkSecurityInterceptEndpointGroupTimeouts;
}
export interface NetworkSecurityInterceptEndpointGroupAssociations {
}
export declare function networkSecurityInterceptEndpointGroupAssociationsToTerraform(struct?: NetworkSecurityInterceptEndpointGroupAssociations): any;
export declare function networkSecurityInterceptEndpointGroupAssociationsToHclTerraform(struct?: NetworkSecurityInterceptEndpointGroupAssociations): any;
export declare class NetworkSecurityInterceptEndpointGroupAssociationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NetworkSecurityInterceptEndpointGroupAssociations | undefined;
    set internalValue(value: NetworkSecurityInterceptEndpointGroupAssociations | undefined);
    get name(): string;
    get network(): string;
    get state(): string;
}
export declare class NetworkSecurityInterceptEndpointGroupAssociationsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NetworkSecurityInterceptEndpointGroupAssociationsOutputReference;
}
export interface NetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocations {
}
export declare function networkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocationsToTerraform(struct?: NetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocations): any;
export declare function networkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocationsToHclTerraform(struct?: NetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocations): any;
export declare class NetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocations | undefined;
    set internalValue(value: NetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocations | undefined);
    get location(): string;
    get state(): string;
}
export declare class NetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocationsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocationsOutputReference;
}
export interface NetworkSecurityInterceptEndpointGroupConnectedDeploymentGroup {
}
export declare function networkSecurityInterceptEndpointGroupConnectedDeploymentGroupToTerraform(struct?: NetworkSecurityInterceptEndpointGroupConnectedDeploymentGroup): any;
export declare function networkSecurityInterceptEndpointGroupConnectedDeploymentGroupToHclTerraform(struct?: NetworkSecurityInterceptEndpointGroupConnectedDeploymentGroup): any;
export declare class NetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NetworkSecurityInterceptEndpointGroupConnectedDeploymentGroup | undefined;
    set internalValue(value: NetworkSecurityInterceptEndpointGroupConnectedDeploymentGroup | undefined);
    private _locations;
    get locations(): NetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupLocationsList;
    get name(): string;
}
export declare class NetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupOutputReference;
}
export interface NetworkSecurityInterceptEndpointGroupTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group#create NetworkSecurityInterceptEndpointGroup#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group#delete NetworkSecurityInterceptEndpointGroup#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group#update NetworkSecurityInterceptEndpointGroup#update}
    */
    readonly update?: string;
}
export declare function networkSecurityInterceptEndpointGroupTimeoutsToTerraform(struct?: NetworkSecurityInterceptEndpointGroupTimeouts | cdktf.IResolvable): any;
export declare function networkSecurityInterceptEndpointGroupTimeoutsToHclTerraform(struct?: NetworkSecurityInterceptEndpointGroupTimeouts | cdktf.IResolvable): any;
export declare class NetworkSecurityInterceptEndpointGroupTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NetworkSecurityInterceptEndpointGroupTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: NetworkSecurityInterceptEndpointGroupTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group google_network_security_intercept_endpoint_group}
*/
export declare class NetworkSecurityInterceptEndpointGroup extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_network_security_intercept_endpoint_group";
    /**
    * Generates CDKTF code for importing a NetworkSecurityInterceptEndpointGroup resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NetworkSecurityInterceptEndpointGroup to import
    * @param importFromId The id of the existing NetworkSecurityInterceptEndpointGroup that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NetworkSecurityInterceptEndpointGroup to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.36.1/docs/resources/network_security_intercept_endpoint_group google_network_security_intercept_endpoint_group} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NetworkSecurityInterceptEndpointGroupConfig
    */
    constructor(scope: Construct, id: string, config: NetworkSecurityInterceptEndpointGroupConfig);
    private _associations;
    get associations(): NetworkSecurityInterceptEndpointGroupAssociationsList;
    private _connectedDeploymentGroup;
    get connectedDeploymentGroup(): NetworkSecurityInterceptEndpointGroupConnectedDeploymentGroupList;
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _interceptDeploymentGroup?;
    get interceptDeploymentGroup(): string;
    set interceptDeploymentGroup(value: string);
    get interceptDeploymentGroupInput(): string | undefined;
    private _interceptEndpointGroupId?;
    get interceptEndpointGroupId(): string;
    set interceptEndpointGroupId(value: string);
    get interceptEndpointGroupIdInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get reconciling(): cdktf.IResolvable;
    get state(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): NetworkSecurityInterceptEndpointGroupTimeoutsOutputReference;
    putTimeouts(value: NetworkSecurityInterceptEndpointGroupTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | NetworkSecurityInterceptEndpointGroupTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
